#!/bin/bash
#
# This script is executed only once, immediately after the image
# tarball is unpacked to the app partition (/usr/local).
#

function need_replace {

	old_v=`expr match "\`cat ${1}\`" ".*VERSION=\([0-9]*\)"`
	new_v=`expr match "\`cat ${2}\`" ".*VERSION=\([0-9]*\)"`

	if [ "${old_v}" = "" ]; then
		return 0
	fi

	if [ "${old_v}" -ge "${new_v}" ]; then
		return 1
	else
		return 0
	fi

	return 0
}

# update ld.so.cache
mount -oremount,rw /
/sbin/ldconfig

if [ ! -d /lib/modules ]; then
	mkdir /lib/modules
fi

if [ ! -f /lib/modules/resetjumper.ko ]; then
	cp /usr/local/modules/resetjumper.ko /lib/modules
fi

if [ ! -c /dev/bfpga ] ; then
	mknod /dev/bfpga c 254 0
fi

# remove libsqlite3 (if installed)
libsqlite3_files="/usr/bin/sqlite3 /usr/lib/libsqlite3.so /usr/lib/libsqlite3.so.0.8.6 /usr/lib/libsqlite3.so.0 /usr/lib/pkgconfig/sqlite3.pc /usr/include/sqlite3.h /usr/include/sqlite3ext.h"
for file in ${libsqlite3_files}; do
	if [ -f ${file} ]; then
		rm -f ${file}
	fi
done

if [ ! -f /usr/lib/mod_auth.so ] ; then
    cp /usr/local/conf/mod_auth.so /usr/lib/
    cp /usr/local/conf/lighttpd.conf /etc/
fi

if need_replace "/etc/init.d/S40network" "/usr/local/conf/S40network" ; then
    cp /usr/local/conf/S40network /etc/init.d/
fi

if need_replace "/usr/sbin/update-time" "/usr/local/conf/update-time" ; then
    cp /usr/local/conf/update-time /usr/sbin/
fi

if need_replace "/etc/init.d/S30factorydef" "/usr/local/conf/S30factorydef" ; then
    cp /usr/local/conf/S30factorydef /etc/init.d/
fi

if need_replace "/usr/www/cgi-bin/update-tool.php" "/usr/local/conf/update-tool.php" ; then
    cp /usr/local/conf/update-tool.php /usr/www/cgi-bin/
fi

if need_replace "/etc/init.d/S90app" "/usr/local/conf/S90app" ; then
    cp /usr/local/conf/S90app /etc/init.d/
fi

if need_replace "/etc/init.d/S99finishprod" "/usr/local/conf/S99finishprod" ; then
    cp /usr/local/conf/S99finishprod /etc/init.d/
fi

bftype=$(sed "s/.*carduuid=//" /proc/cmdline | sed "s/ revision.*//"  | cut -d "-" -f2)

if [ "$bftype" = "64" ] ; then
        if [ -c /dev/ttyS0 ] ; then
                mv /dev/ttyS0 /dev/ttyS0_off
        fi
fi

mount -oremount,ro /


if [ ! -d /usr/local/www/api ] ; then
    mkdir -p /usr/local/www/api
fi

if [ ! -f /usr/conf/apiusers.conf ] ; then
    echo "admin:admin" > /usr/conf/apiusers.conf
fi

if [ ! -f /usr/conf/isgw.tones ] ; then
	cp /usr/local/conf/isgw.tones /usr/conf
fi

if [ ! -f /usr/conf/isgw.causes ] ; then
	cp /usr/local/conf/isgw.causes /usr/conf
fi

/usr/bin/dos2unix -u /usr/conf/isgw.causes

MTU=$(/usr/local/bin/beroconf get root lan-mtu)
if [ "$MTU" = "500" ] ; then
        /usr/local/bin/beroconf set root lan-mtu 1500
fi


/usr/bin/env -i bash -c "/usr/bin/php-cgi /usr/local/www/berogui/includes/create_files.php  > /dev/null"

